@@ -5,7 +5,7 @@ print( paste("Threshold = ", z$threshold, sep=""))
 cat("\n")
 print( paste("Number of exceedances of threshold = ", z$nexc, sep=""))
 cat("\n")
-print( paste("Exceedance rate = (per year)", z$rate*z$npy, sep=""))
+print( paste("Exceedance rate (per year) = ", z$rate*z$npy, sep=""))
 cat("\n")
 print( z$summary1)
 
